##  Antipatterns
  * Do not use the system fact sheet to model applications. An application is a software system or program that directly supports business capabilities and processes within a business context.
  * Don’t add relations like business capabilities, business context, or organizations to the System fact sheet; these belong to application fact sheets. Systems are related to the business layer through the application fact sheet.
